/*
 * Entagged Audio Tag library
 * Copyright (c) 2003-2005 Raphal Slinckx <raphael@slinckx.net>
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *  
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
package entagged.audioformats.mp3;

import entagged.audioformats.generic.AbstractTag;
import entagged.audioformats.generic.TagField;
import entagged.audioformats.mp3.util.id3frames.*;

public class Id3v2Tag extends AbstractTag {
	public static String DEFAULT_ENCODING = "UTF-16";
	
	public static byte ID3V22 = 0;
	public static byte ID3V23 = 1;
	
	private boolean hasV1 = false;
	
	protected String getArtistId() {
	    return "TPE1";
	}
    protected String getAlbumId() {
        return "TALB";
    }
    protected String getTitleId() {
        return "TIT2";
    }
    protected String getTrackId() {
        return "TRCK";
    }
    protected String getYearId() {
        return "TYER";
    }
    protected String getCommentId() {
        return "COMM";
    }
    protected String getGenreId() {
        return "TCON";
    }
    
    protected TagField createArtistField(String content) {
        return new TextId3Frame("TPE1", content);
    }
    protected TagField createAlbumField(String content) {
        return new TextId3Frame("TALB", content);
    }
    protected TagField createTitleField(String content) {
        return new TextId3Frame("TIT2", content);
    }
    protected TagField createTrackField(String content) {
        return new TextId3Frame("TRCK", content);
    }
    protected TagField createYearField(String content) {
        return new TextId3Frame("TYER", content);
    }
    protected TagField createCommentField(String content) {
        return new CommId3Frame(content);
    }
    protected TagField createGenreField(String content) {
        return new TextId3Frame("TCON", content);
    }
	
    protected boolean isAllowedEncoding(String enc) {
        return enc.equals("ISO-8859-1") ||
        	   enc.equals("UTF-16");
    }
    
    public boolean hasId3v1() {
        return hasV1;
    }
    
    protected void hasId3v1(boolean b) {
        this.hasV1 = b;
    }
    
	public String toString() {
		return "Id3v2 "+super.toString();
	}
}

